### R code from vignette source 'caseStudy.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: pubmedArticles
###################################################
library(ggplot2)

data.file <- system.file(
  paste0("extdata", .Platform$file.sep, "psychiatricDisordersPubmed.csv"), 
  package="psygenet2r"
)

pmid <- read.delim(data.file, header=TRUE, sep=",")
pmid <- pmid[pmid$year<2017 & pmid$year>1950,]

pmid$year <- factor(pmid$year)
labels <- as.integer(seq(1950, 2016, by=5))

p <- ggplot(pmid, aes ( x = year, y = count ) ) +
    geom_bar ( stat = "identity", fill = "grey" ) +
    labs ( title = "Number of publications for psychiatric disorders in PubMed" , x = "year", y = "# of pmids") +
    theme_classic( ) + 
    scale_x_discrete(breaks=labels, labels=as.character(labels))+
    theme( plot.margin = grid::unit ( x = c ( 5, 15, 5, 15 ), units = "mm" ),
                                     axis.line = element_line ( size = 0.7, color = "black" ), 
           text = element_text ( size = 14 ) ,
           axis.text.x = element_text ( angle = 45, size = 11, hjust = 1 ) )

p


###################################################
### code chunk number 2: bioC (eval = FALSE)
###################################################
## source( "http://bioconductor.org/biocLite.R" )
## biocLite( "psyGeNET2R" )


###################################################
### code chunk number 3: load_library
###################################################
library( psygenet2r )


###################################################
### code chunk number 4: genes
###################################################
genesOfInterest <- c("ADCY2", "AKAP13", "ANK3", "ANKS1A", 
"ATP6V1G3", "ATXN1", "C11orf80", "C15orf53", "CACNA1C", 
"CACNA1D", "CACNB3", "CROT", "DLG2", "DNAJB4", "DUSP22", 
"FAM155A", "FLJ16124", "FSTL5", "GATA5", "GNA14", "GPR81", 
"HHAT", "IFI44", "ITIH3", "KDM5B", "KIF1A", "LOC150197", 
"MAD1L1", "MAPK10", "MCM9", "MSI2", "NFIX", "NGF", "NPAS3", 
"ODZ4", "PAPOLG", "PAX1", "PBRM1", "PTPRE", "PTPRT", 
"RASIP1", "RIMBP2", "RXRG", "SGCG", "SH3PXD2A", "SIPA1L2",
"SNX8", "SPERT", "STK39", "SYNE1", "THSD7A", "TNR", 
"TRANK1", "TRIM9", "UBE2E3", "UBR1", "ZMIZ1", "ZNF274")


###################################################
### code chunk number 5: search_multiple
###################################################
m1 <- psygenetGene(
    gene     = genesOfInterest, 
    database = "ALL",
    verbose  = FALSE,
    warnings = FALSE
)
m1


###################################################
### code chunk number 6: plot_disease_m
###################################################
plot( m1 )


###################################################
### code chunk number 7: plot_psychiatric_m1Score
###################################################
geneAttrPlot( m1, type = "index" )


###################################################
### code chunk number 8: ggplot_panther
###################################################
pantherGraphic( genesOfInterest, "ALL")


###################################################
### code chunk number 9: heatmap_disease_m
###################################################
plot( m1, type="heatmapGenes")


###################################################
### code chunk number 10: pmids_barplot
###################################################
plot( m1, name="bipolar disorder", type="barplot")


###################################################
### code chunk number 11: sentences1_query
###################################################
m2 <- psygenetGeneSentences(
    geneList = genesOfInterest, 
    database = "ALL"
)
m2


###################################################
### code chunk number 12: sentences2_extraction
###################################################
sentences <- extractSentences( m2, 
  disorder = "bipolar disorder" )
head(sentences$PUBMED_ID)


###################################################
### code chunk number 13: jaccard_1
###################################################
xx <- jaccardEstimation( genesOfInterest, "bipolar disorder", 
  database = "ALL", nboot = 500 )
xx


###################################################
### code chunk number 14: jaccard_2
###################################################
extract( xx )


###################################################
### code chunk number 15: jaccard_3
###################################################
xx <- jaccardEstimation( genesOfInterest, 
  database = "ALL", nboot = 500 )


###################################################
### code chunk number 16: jaccard_4
###################################################
plot( xx )


###################################################
### code chunk number 17: plot_bpGenes
###################################################
geneAttrPlot( m1, type = "category" )


###################################################
### code chunk number 18: plot_bpDis
###################################################
geneAttrPlot( m1, type = "gene" )


