### R code from vignette source 'generalOverview.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: bioC (eval = FALSE)
###################################################
## source( "http://bioconductor.org/biocLite.R" )
## biocLite( "psygenet2r" )


###################################################
### code chunk number 2: load_library (eval = FALSE)
###################################################
## library( psygenet2r )


###################################################
### code chunk number 3: load_library_2
###################################################
suppressMessages(suppressWarnings(library( psygenet2r )))


###################################################
### code chunk number 4: dataGenet1
###################################################
t1 <- psygenetGene( gene = 4852, 
                    database = "ALL")


###################################################
### code chunk number 5: dataGenet2
###################################################
t1
class( t1 )


###################################################
### code chunk number 6: search_gene_1
###################################################
t1 <- psygenetGene( gene = 4852, 
                    database = "ALL")
t1


###################################################
### code chunk number 7: search_gene_2
###################################################
t2 <- psygenetGene( gene = "NPY", database = "ALL" )
t2


###################################################
### code chunk number 8: searcg_gene_class
###################################################
class( t1 )
class( t2 )


###################################################
### code chunk number 9: plot_disease
###################################################
plot( t1, type = "individual disease" )


###################################################
### code chunk number 10: plot_psychiatric
###################################################
plot( t1, type = "disease class" )


###################################################
### code chunk number 11: search_multiple_genes
###################################################
genesOfInterest <- c( "COMT", "CLOCK", "DRD3", "GNB3", "HTR1A",
                      "MAOA", "HTR2A","HTR2C", "HTR6", "SLC6A4", 
                      "ACE",  "BDNF", "DRD4", "HTR1B", "HTR2B",
                      "HTR2C", "MTHFR", "SLC6A3", "TPH1", "SLC6A2", 
                      "GABRA3"
)


###################################################
### code chunk number 12: search_multiple_search
###################################################
m1 <- psygenetGene(
    gene     = genesOfInterest, 
    database = "ALL",
    verbose  = TRUE
)


###################################################
### code chunk number 13: show_multiple
###################################################
m1


###################################################
### code chunk number 14: plot_psychiatric1a
###################################################
plot( m1 )


###################################################
### code chunk number 15: plot_psychiatric1b
###################################################
plot( m1, type = "disease class" )


###################################################
### code chunk number 16: heatmap_disease_m
###################################################
plot( m1, type="heatmapGenes" )


###################################################
### code chunk number 17: plot_psychiatric_heamap
###################################################
plot( m1, type = "heatmap" )


###################################################
### code chunk number 18: panther_gene
###################################################
genesOfInterest <- unique( genesOfInterest )
pantherGraphic( genesOfInterest, "ALL" )


###################################################
### code chunk number 19: plot_diseaseBarplot
###################################################
geneAttrPlot( m1, type = "category" )


###################################################
### code chunk number 20: plot_diseaseBarplotGene
###################################################
geneAttrPlot( m1, type = "gene" )


###################################################
### code chunk number 21: plot_pieChart
###################################################
geneAttrPlot( m1, type = "pie" )


###################################################
### code chunk number 22: barplotIP
###################################################
geneAttrPlot( m1, type = "index" )


###################################################
### code chunk number 23: enrichment
###################################################
tbl <- enrichedPD( genesOfInterest, database = "ALL")
tbl


###################################################
### code chunk number 24: topAnat
###################################################
tpAnat <- topAnatEnrichment( genesOfInterest, cutOff = 1 )


###################################################
### code chunk number 25: show_topAnat
###################################################
head( tpAnat )


###################################################
### code chunk number 26: gda_sentenceGene
###################################################
genesOfInterest
sss <- psygenetGeneSentences( geneList = genesOfInterest,
                             database = "ALL")
sss

geneSentences <- extractSentences( object = sss,
                                   disorder = "alcohol abuse")
dim( geneSentences )


###################################################
### code chunk number 27: getUMLS
###################################################
getUMLs( "depressive", database = "ALL" )


###################################################
### code chunk number 28: search_diseaseId_1
###################################################
d1 <- psygenetDisease( disease  = "umls:C1839839", 
                       database = "ALL", 
                       score    = c('>', 0.5 ) )
d1


###################################################
### code chunk number 29: search_diseaseName_1
###################################################
d2 <- psygenetDisease( disease = "major affective disorder 2", 
                       database = "ALL",
                       score    = c('>', 0.5 ) )
d2


###################################################
### code chunk number 30: search_gene_class
###################################################
class( d1 )
class( d2 )


###################################################
### code chunk number 31: plot_visualizing_single_disease_search
###################################################
plot ( d1 )


###################################################
### code chunk number 32: diseaseList
###################################################
diseasesOfInterest <- c( "chronic schizophrenia","alcohol use disorder" )


###################################################
### code chunk number 33: search_diseases_1
###################################################
tt <- psygenetDisease( disease  = diseasesOfInterest,
                       database = "ALL" )
tt


###################################################
### code chunk number 34: search_diseases_2
###################################################
dm <- psygenetDisease( disease  = c( "umls:C0221765", "umls:C0001956" ), 
                       database = "ALL" )
dm


###################################################
### code chunk number 35: search_diseases_3
###################################################
tm <- psygenetDisease( disease  = c( "chronic schizophrenia","umls:C0001956" ), 
                       database = "ALL" )
tm


###################################################
### code chunk number 36: search_gene_class_2
###################################################
class( tt )
class( dm )
class( tm )


###################################################
### code chunk number 37: plot_disease_tm
###################################################
plot( tm )


###################################################
### code chunk number 38: heatmap_disease_tm
###################################################
plot( tm, type = "heatmap" )


###################################################
### code chunk number 39: barplot_visualizing_single_disease_search
###################################################
plot( d1, name = "major affective disorder 2", type = "barplot" )


###################################################
### code chunk number 40: barplot_visualizing_single_gene_search
###################################################
plot( t1, name = "NPY", type = "barplot" )


###################################################
### code chunk number 41: ji_1
###################################################
genes_interest <- c("SLC6A4", "DRD2", "HTR1B", "PLP1", "TH", "DRD3")
ji1 <- jaccardEstimation(genes_interest, database = "ALL")


###################################################
### code chunk number 42: ji_2
###################################################
disease_interest <- 
  c("delirium", "bipolar i disorder", "severe depression", "cocaine dependence")
ji2 <- jaccardEstimation(genes_interest, disease_interest, database = "ALL")


###################################################
### code chunk number 43: ji_3
###################################################
ji3 <- jaccardEstimation(disease_interest, database = "ALL")


###################################################
### code chunk number 44: ji1_extract
###################################################
head(extract(ji1))
tail(extract(ji1))


###################################################
### code chunk number 45: ji1_plot
###################################################
plot(ji1, cutOff = 0.1)


###################################################
### code chunk number 46: ji2_plot
###################################################
plot(ji2)


###################################################
### code chunk number 47: ji3_plot
###################################################
plot(ji3)


